@@ -21,8 +21,7 @@ import (
 // AddToManagerFuncs is a list of functions to add all Controllers to the Manager
 var AddToManagerFuncs []func(manager.Manager) error
 
-// AddArgocdClusterToManagerFuncs is a list of functions to add all Controllers to the Manager
-var AddArgocdClusterToManagerFuncs []func(manager.Manager) error
+var AddGitOpsClusterToManagerFuncs []func(manager.Manager) error
 
 // AddToManager adds all Controllers to the Manager
 func AddToManager(m manager.Manager) error {
@@ -35,9 +34,8 @@ func AddToManager(m manager.Manager) error {
 	return nil
 }
 
-// AddArgocdToManager adds all ArgocdCluster Controllers to the Manager
-func AddArgocdClusterToManager(m manager.Manager) error {
-	for _, f := range AddArgocdClusterToManagerFuncs {
+func AddGitOpsClusterToManager(m manager.Manager) error {
+	for _, f := range AddGitOpsClusterToManagerFuncs {
 		if err := f(m); err != nil {
 			return err
 		}
