@@ -20,7 +20,7 @@ import (
 	"strings"
 
 	spokeClusterV1 "github.com/open-cluster-management/api/cluster/v1"
-	appv1 "github.com/stolostron/multicloud-operators-placementrule/pkg/apis/apps/v1"
+	appv1 "github.com/open-cluster-management/multicloud-operators-placementrule/pkg/apis/apps/v1"
 	rbacv1 "k8s.io/api/authorization/v1"
 	"k8s.io/apimachinery/pkg/api/meta"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -29,6 +29,18 @@ import (
 	"k8s.io/klog"
 )
 
+var (
+	AdminUsers = map[string]bool{
+		"admin":                               true,
+		"multicluster-observability-operator": true,
+		"openshift-gitops-argocd-application-controller": true,
+	}
+	AdminGroups = map[string]bool{
+		"masters":        true,
+		"cluster-admins": true,
+	}
+)
+
 func FilteClustersByIdentity(authClient kubernetes.Interface, object runtime.Object, clmap map[string]*spokeClusterV1.ManagedCluster) error {
 	objmeta, err := meta.Accessor(object)
 	if err != nil {
@@ -90,7 +102,7 @@ func filterClusterByUserIdentity(
 	filteredClusters := []*spokeClusterV1.ManagedCluster{}
 
 	for _, cluster := range clusters {
-		user, groups := extractUserAndGroup(annotations)
+		user, groups := ExtractUserAndGroup(annotations)
 		sar := &rbacv1.SubjectAccessReview{
 			Spec: rbacv1.SubjectAccessReviewSpec{
 				ResourceAttributes: &rbacv1.ResourceAttributes{
@@ -119,7 +131,8 @@ func filterClusterByUserIdentity(
 
 	return filteredClusters
 }
-func extractUserAndGroup(annotations map[string]string) (string, []string) {
+
+func ExtractUserAndGroup(annotations map[string]string) (string, []string) {
 	var user string
 
 	var groups []string
@@ -142,3 +155,31 @@ func extractUserAndGroup(annotations map[string]string) (string, []string) {
 
 	return user, groups
 }
+
+func IfClusterAdmin(user string, groups []string) bool {
+	newUser := user
+
+	ss := strings.Split(user, ":")
+	if len(ss) > 0 {
+		newUser = ss[len(ss)-1]
+	}
+
+	if _, ok := AdminUsers[newUser]; ok {
+		return true
+	}
+
+	for _, group := range groups {
+		newGroup := group
+
+		gg := strings.Split(group, ":")
+		if len(gg) > 0 {
+			newGroup = gg[len(gg)-1]
+		}
+
+		if _, ok := AdminGroups[newGroup]; ok {
+			return true
+		}
+	}
+
+	return false
+}
